pub enum ReadyState {
Connecting = 0,
Open = 1,
Closed = 2,
}Expand description
The connection state mapping to the JavaScript EventSource API readyState.
Variants
Connecting = 0
The connection has not yet been established, or it was closed and the client is reconnecting.
Open = 1
The connection is open and ready to receive events.
Closed = 2
The connection is permanently closed and will not reconnect.